asm

main:
    ld sp, $dff0

    ;==============================================================
    ; Set up VDP registers
    ;==============================================================
    ld hl,VdpData
    ld b,VdpDataEnd-VdpData
    ld c,$bf
    otir

    ;==============================================================
    ; Clear VRAM
    ;==============================================================
    ; 1. Set VRAM write address to 0 by outputting $4000 ORed with $0000
    ld a,$00
    out ($bf),a
    ld a,$40
    out ($bf),a
    ; 2. Output 16KB of zeroes
    ld bc, $4000    ; Counter for 16KB of VRAM
    ClearVRAMLoop:
        ld a,$00    ; Value to write
        out ($be),a ; Output to VRAM address, which is auto-incremented after each write
        dec bc
        ld a,b
        or c
        jp nz,ClearVRAMLoop

    ;==============================================================
    ; Load palette
    ;==============================================================
    ; 1. Set VRAM write address to CRAM (palette) address 0 (for palette index 0)
    ; by outputting $c000 ORed with $0000
    ld a,$00
    out ($bf),a
    ld a,$c0
    out ($bf),a
    ; 2. Output colour data
    ld hl,PaletteData
    ld b,(PaletteDataEnd-PaletteData)
    ld c,$be
    otir

;    ;==============================================================
;    ; Load tiles (font)
;    ;==============================================================
;    ; 1. Set VRAM write address to tile index 0
;    ; by outputting $4000 ORed with $0000
;    ld a,$00
;    out ($bf),a
;    ld a,$40
;    out ($bf),a
;    ; 2. Output tile data
;    ld hl,FontData              ; Location of tile data
;    ld bc,FontDataEnd-FontData  ; Counter for number of bytes to write
;    WriteTilesLoop:
;        ; Output data byte then three zeroes, because our tile data is 1 bit
;        ; and must be increased to 4 bit
;        ld a,(hl)        ; Get data byte
;        out ($be),a
;        inc hl           ; Add one to hl so it points to the next data byte
;        dec bc
;        ld a,b
;        or c
;        jp nz,WriteTilesLoop


    ;==============================================================
    ; Load tiles (font) (b)
    ;==============================================================
    ; 1. Set VRAM write address to tile index 0
    ; by outputting $4000 ORed with $0000
    ld a,$00
    out ($bf),a
    ld a,$40
    out ($bf),a
    ; 2. Output tile data
    ld hl,FontData              ; Location of tile data
    ld bc,FontDataEnd-FontData  ; Counter for number of bytes to write
    WriteTilesLoop:
        ; Output data byte then three zeroes, because our tile data is 1 bit
        ; and must be increased to 4 bit
        ld a,(hl)        ; Get data byte
        out ($be),a
        ld a,0
        out ($be),a
        out ($be),a
        out ($be),a
        inc hl           ; Add one to hl so it points to the next data byte
        dec bc
        ld a,b
        or c
        jp nz,WriteTilesLoop





    ;==============================================================
    ; Write text to name table
    ;==============================================================
    ; 1. Set VRAM write address to name table index 0
    ; by outputting $4000 ORed with $3800+0
    ld a,$00
    out ($bf),a
    ld a,$78     ;- ld a,$38|$40 
    out ($bf),a
    ; 2. Output tilemap data
    ld hl,Message
    ld bc,MessageEnd-Message  ; Counter for number of bytes to write
    WriteTextLoop:
        ld a,(hl)    ; Get data byte
        out ($be),a
        inc hl       ; Point to next letter
        dec bc
        ld a,b
        or c
        jp nz,WriteTextLoop

    ; Turn screen on
    ld a,%11000000
;          |||| |`- Zoomed sprites -> 16x16 pixels
;          |||| `-- Doubled sprites -> 2 tiles per sprite, 8x16
;          |||`---- 30 row/240 line mode
;          ||`----- 28 row/224 line mode
;          |`------ VBlank interrupts
;          `------- Enable display
    out ($bf),a
    ld a,$81
    out ($bf),a

    ; Infinite loop to stop program
Loop:
     jp Loop

;==============================================================
; Data
;==============================================================

; VDP initialisation data
VdpData:
defb $04,$80
defb $84,$81
defb $ff,$82
defb $ff,$85
defb $ff,$86
defb $ff,$87
defb $30,$88 ;defb $30,$88  ;- scroll x
defb $c8,$89 ;defb $18,$89  ;- scroll y
defb $ff,$8a
VdpDataEnd:



Message:
defw $20,$21,$22,$23,$24,$25,$26,$27,$28,$29,$2A,$2B,$2C,$2D,$2E,$2F,$30,$31,$32,$33
defw $00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00
defw $34,$35,$36,$37,$38,$39,$3A,$3B,$3C,$3D,$3E,$3F,$40,$41,$42,$43,$44,$45,$46,$47
defw $00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00
defw $48,$49,$4A,$4B,$4C,$4D,$4E,$4F,$50,$51,$52,$53,$54,$55,$56,$57,$58,$59,$5A,$5B
defw $00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00
defw $5C,$5D,$5E,$5F,$60,$61,$62,$63,$64,$65,$66,$67,$68,$69,$6A,$6B,$6C,$6D,$6E,$6F
defw $00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00
defw $70,$71,$72,$73,$74,$75,$76,$77,$78,$79,$7A,$7B,$7C,$7D,$7E,$7F,$80,$81,$82,$83
defw $00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00
defw $00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00
defw $00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00

defb "H@e@l@l@o@ @W@o@r@l@d@!@!@!@"
;defw $48,$65,$6c,$6c,$6f,$00,$57,$6f,$72,$6c,$64,$21,$00

MessageEnd:

PaletteData:

defw $0457
defw $0877

;defb %00011111
;defb %00100000

;defb $00
;defb $3f

PaletteDataEnd:


FontData:
  defb 000h,000h,000h,000h,000h,000h,000h,000h
  defb 000h,000h,000h,000h,000h,000h,000h,000h
  defb 000h,000h,000h,000h,000h,000h,000h,000h
  defb 000h,000h,000h,000h,000h,000h,000h,000h
  defb 000h,000h,000h,000h,000h,000h,000h,000h
  defb 000h,000h,000h,000h,000h,000h,000h,000h
  defb 000h,000h,000h,000h,000h,000h,000h,000h
  defb 000h,000h,000h,000h,000h,000h,000h,000h
  defb 000h,000h,000h,000h,000h,000h,000h,000h
  defb 000h,000h,000h,000h,000h,000h,000h,000h
  defb 000h,000h,000h,000h,000h,000h,000h,000h
  defb 000h,000h,000h,000h,000h,000h,000h,000h
  defb 000h,000h,000h,000h,000h,000h,000h,000h
  defb 000h,000h,000h,000h,000h,000h,000h,000h
  defb 000h,000h,000h,000h,000h,000h,000h,000h
  defb 000h,000h,000h,000h,000h,000h,000h,000h

  defb 000h,000h,000h,000h,000h,000h,000h,000h
  defb 000h,000h,000h,000h,000h,000h,000h,000h
  defb 000h,000h,000h,000h,000h,000h,000h,000h
  defb 000h,000h,000h,000h,000h,000h,000h,000h
  defb 000h,000h,000h,000h,000h,000h,000h,000h
  defb 000h,000h,000h,000h,000h,000h,000h,000h
  defb 000h,000h,000h,000h,000h,000h,000h,000h
  defb 000h,000h,000h,000h,000h,000h,000h,000h
  defb 000h,000h,000h,000h,000h,000h,000h,000h
  defb 000h,000h,000h,000h,000h,000h,000h,000h
  defb 000h,000h,000h,000h,000h,000h,000h,000h
  defb 000h,000h,000h,000h,000h,000h,000h,000h
  defb 000h,000h,000h,000h,000h,000h,000h,000h
  defb 000h,000h,000h,000h,000h,000h,000h,000h
  defb 000h,000h,000h,000h,000h,000h,000h,000h
  defb 000h,000h,000h,000h,000h,000h,000h,000h

  defb 000h,000h,000h,000h,000h,000h,000h,000h
  defb 000h,01ch,01ch,01ch,01ch,000h,01ch,000h
  defb 000h,076h,076h,000h,000h,000h,000h,000h
  defb 000h,03bh,07fh,03bh,03bh,07fh,03bh,000h
  defb 000h,00ch,07fh,070h,07fh,003h,07fh,00ch
  defb 000h,073h,007h,00eh,01ch,038h,073h,000h
  defb 000h,07eh,076h,03ch,077h,076h,07fh,000h
  defb 000h,00ch,038h,000h,000h,000h,000h,000h
  defb 000h,00eh,038h,038h,038h,038h,00eh,000h
  defb 000h,038h,00eh,00eh,00eh,00eh,038h,000h
  defb 000h,000h,073h,00ch,07fh,00ch,073h,000h
  defb 000h,000h,01ch,01ch,07fh,01ch,01ch,000h
  defb 000h,000h,000h,000h,000h,000h,01ch,07ch
  defb 000h,000h,000h,000h,07ch,000h,000h,000h
  defb 000h,000h,000h,000h,000h,000h,038h,000h
  defb 000h,003h,007h,00eh,01ch,038h,070h,000h
  defb 000h,07fh,073h,073h,073h,073h,07fh,000h
  defb 000h,03eh,00eh,00eh,00eh,00eh,00eh,000h
  defb 000h,07fh,073h,003h,07fh,070h,07fh,000h
  defb 000h,07fh,073h,00fh,003h,073h,07fh,000h
  defb 000h,073h,073h,073h,07fh,003h,003h,000h
  defb 000h,07fh,070h,07fh,003h,073h,07fh,000h
  defb 000h,07fh,070h,07fh,073h,073h,07fh,000h
  defb 000h,07fh,003h,003h,03fh,038h,038h,000h
  defb 000h,07fh,073h,00ch,073h,073h,07fh,000h
  defb 000h,07fh,073h,073h,07fh,003h,07fh,000h
  defb 000h,000h,000h,01ch,000h,000h,01ch,000h
  defb 000h,000h,000h,01ch,000h,000h,01ch,07ch
  defb 000h,000h,01ch,038h,070h,038h,01ch,000h
  defb 000h,000h,000h,07eh,000h,07eh,000h,000h
  defb 000h,000h,070h,038h,01ch,038h,070h,000h
  defb 000h,07fh,073h,003h,00fh,000h,00ch,000h
  defb 000h,07fh,073h,07fh,07fh,070h,07fh,000h
  defb 000h,07fh,073h,073h,07fh,073h,073h,000h
  defb 000h,07fh,073h,07ch,073h,073h,07fh,000h
  defb 000h,07fh,073h,070h,070h,073h,07fh,000h
  defb 000h,07ch,073h,073h,073h,073h,07ch,000h
  defb 000h,07fh,070h,07fh,070h,070h,07fh,000h
  defb 000h,07fh,070h,07fh,070h,070h,070h,000h
  defb 000h,07fh,073h,070h,077h,073h,07fh,000h
  defb 000h,073h,073h,07fh,073h,073h,073h,000h
  defb 000h,03fh,00eh,00eh,00eh,00eh,03fh,000h
  defb 000h,00fh,003h,003h,003h,073h,07fh,000h
  defb 000h,073h,073h,07ch,073h,073h,073h,000h
  defb 000h,070h,070h,070h,070h,070h,07fh,000h
  defb 000h,073h,07fh,07fh,07fh,073h,073h,000h
  defb 000h,073h,07fh,077h,073h,073h,073h,000h
  defb 000h,07fh,073h,073h,073h,073h,07fh,000h
  defb 000h,07fh,073h,073h,07fh,070h,070h,000h
  defb 000h,07fh,073h,073h,077h,073h,07fh,000h
  defb 000h,07fh,073h,073h,07ch,073h,073h,000h
  defb 000h,07fh,070h,07fh,003h,003h,07fh,000h
  defb 000h,0ffh,01ch,01ch,01ch,01ch,01ch,000h
  defb 000h,073h,073h,073h,073h,073h,07fh,000h
  defb 000h,073h,073h,073h,073h,07fh,00ch,000h
  defb 000h,073h,073h,07fh,07fh,07fh,073h,000h
  defb 000h,073h,073h,00ch,073h,073h,073h,000h
  defb 000h,073h,073h,07fh,00ch,00ch,00ch,000h
  defb 000h,07fh,003h,07fh,070h,070h,07fh,000h
  defb 000h,03eh,038h,038h,038h,038h,03eh,000h
  defb 000h,070h,038h,01ch,00eh,007h,003h,000h
  defb 000h,03eh,00eh,00eh,00eh,00eh,03eh,000h
  defb 000h,01eh,077h,000h,000h,000h,000h,000h
  defb 000h,000h,000h,000h,000h,000h,000h,07eh
  defb 000h,03fh,038h,07fh,038h,038h,07fh,000h
  defb 000h,000h,07eh,006h,07eh,076h,07eh,000h
  defb 000h,070h,07eh,076h,076h,076h,07eh,000h
  defb 000h,000h,03eh,038h,038h,038h,03eh,000h
  defb 000h,006h,07eh,076h,076h,076h,07eh,000h
  defb 000h,000h,07eh,076h,07eh,070h,07eh,000h
  defb 000h,03eh,038h,03ch,038h,038h,038h,000h
  defb 000h,000h,07eh,076h,076h,07eh,006h,07eh
  defb 000h,070h,07eh,076h,076h,076h,076h,000h
  defb 01ch,000h,03ch,01ch,01ch,01ch,03eh,000h
  defb 006h,000h,00eh,006h,006h,006h,076h,07eh
  defb 000h,070h,076h,076h,078h,076h,076h,000h
  defb 000h,038h,038h,038h,038h,038h,03eh,000h
  defb 000h,000h,0ffh,0ffh,0ffh,0ffh,0ffh,000h
  defb 000h,000h,07eh,076h,076h,076h,076h,000h
  defb 000h,000h,07eh,076h,076h,076h,07eh,000h
  defb 000h,000h,07eh,076h,076h,07eh,070h,070h
  defb 000h,000h,07eh,076h,076h,07eh,006h,006h
  defb 000h,000h,07eh,076h,070h,070h,070h,000h
  defb 000h,000h,07eh,070h,07eh,006h,07eh,000h
  defb 000h,038h,07ch,038h,038h,038h,03eh,000h
  defb 000h,000h,076h,076h,076h,076h,07eh,000h
  defb 000h,000h,076h,076h,076h,07eh,008h,000h
  defb 000h,000h,076h,076h,07eh,07eh,076h,000h
  defb 000h,000h,076h,076h,008h,076h,076h,000h
  defb 000h,000h,076h,076h,076h,07eh,006h,07eh
  defb 000h,000h,07eh,006h,07eh,070h,07eh,000h
  defb 000h,01fh,01ch,07ch,01ch,01ch,01fh,000h
  defb 000h,018h,018h,018h,018h,018h,018h,000h
  defb 000h,07ch,01ch,01fh,01ch,01ch,07ch,000h
  defb 000h,07dh,077h,000h,000h,000h,000h,000h
  defb 0ffh,0c1h,0ddh,0cdh,0cdh,0ddh,0c1h,0ffh


FontDataEnd:


end asm
